@@ -12,7 +12,6 @@ pub mod wrapper_types;
 pub mod utils;
 pub mod ft;
 pub mod polynomial;
-pub mod worker;
 
 use polynomial::{Polynomial, SubProductTree, op_tree};
 use wrapper_types::{G1Affine, G2Affine};
@@ -147,7 +146,7 @@ impl<'params, E: Engine> KZGProver<'params, E> {
                 let mut dividend = polynomial.clone();
                 dividend.coeffs[0] -= y;
 
-                let mut divisor = Polynomial::new_from_coeffs(vec![-x, E::Fr::one()], 1);
+                let divisor = Polynomial::new_from_coeffs(vec![-x, E::Fr::one()], 1);
                 match dividend.long_division(&divisor) {
                     // by polynomial remainder theorem, if (x - point.x) does not divide self.polynomial, then
                     // self.polynomial(point.y) != point.1
